@@ -3,13 +3,13 @@ import logging
 import os
 from collections.abc import Mapping
 from datetime import datetime
-from decimal import Decimal
 from typing import MutableMapping
 from uuid import UUID
 
 from satcfdi.accounting import complement_invoices_data, SatCFDI
 
 from .local import load_data, save_data
+from .utils import to_uuid
 
 ALL_INVOICES = 'all_invoices'
 ALL_RETENCIONES = 'all_retenciones'
@@ -20,7 +20,6 @@ PUE = "PUE"
 
 
 class MyCFDI(SatCFDI):
-    issuer_rfc = None
     local_db = None
 
     def consulta_estado(self):
@@ -39,21 +38,6 @@ class MyCFDI(SatCFDI):
     def fecha_cancelacion(self) -> datetime:
         return None
 
-    @SatCFDI.saldo_pendiente.getter
-    def saldo_pendiente(self) -> Decimal:
-        if self['TipoDeComprobante'] == "I":
-            if self["MetodoPago"] == PPD:
-                if self.local_db.ppd_ignorar(self):
-                    return Decimal()
-
-            if self["MetodoPago"] == PUE and not self.payments and self["Emisor"]["Rfc"] == self.issuer_rfc:
-                if self.local_db.pue_pagada(self):
-                    return Decimal()
-                else:
-                    return self['Total']
-
-        return super().saldo_pendiente
-
     @classmethod
     def get_all_invoices(cls, invoices: MutableMapping, search_path="*.xml") -> bool:
         # Check that all names are correct
@@ -95,19 +79,19 @@ class MyCFDI(SatCFDI):
     def filename(self):
         match self.tag:
             case '{http://www.sat.gob.mx/cfd/3}Comprobante' | '{http://www.sat.gob.mx/cfd/4}Comprobante':
-                return "facturas/{3:%Y}/{3:%Y-%m}/{4}/{3:%Y-%m-%d}_{0}_[{1}]_{2}".format(
+                return "facturas/{3:%Y}/{3:%Y-%m}/{4}_{0}_[{1}]_{2}".format(
                     self.name,
                     self["TipoDeComprobante"].code,
                     self.uuid,
                     self["Fecha"],
-                    "Emitidas" if self["Emisor"]["Rfc"] == self.issuer_rfc else "Recibidas"
+                    self["Emisor"]["Rfc"],
                 )
             case '{http://www.sat.gob.mx/esquemas/retencionpago/1}Retenciones' | '{http://www.sat.gob.mx/esquemas/retencionpago/2}Retenciones':
-                return "retenciones/{2:%Y}/{2:%Y-%m}/{3}/{2:%Y-%m-%d}_{0}_{1}".format(
+                return "retenciones/{2:%Y}/{2:%Y-%m}/{3}_{0}_{1}".format(
                     self.get("FolioInt", ""),
                     self.uuid,
                     self["FechaExp"],
-                    "Emitidas" if self["Emisor"]["RFCEmisor"] == self.issuer_rfc else "Recibidas"
+                    self["Emisor"].get('RFCEmisor') or self["Emisor"].get('RfcE')
                 )
 
     @classmethod
@@ -115,21 +99,9 @@ class MyCFDI(SatCFDI):
         filename = os.path.basename(filename)
         parts = os.path.splitext(filename)[0].split("_")
         if len(parts) >= 3:
-            try:
-                return UUID(parts[-1])
-            except ValueError:
-                pass
+            return to_uuid(parts[-1])
         return None
 
-    @property
-    def notified(self) -> bool:
-        return self["Emisor"]["Rfc"] != self.issuer_rfc \
-            or self.local_db.email_notificada(self)
-
-    @notified.setter
-    def notified(self, value: bool):
-        self.local_db.email_notificada_set(self.uuid, value)
-
 
 def rename_invoice(file, invoice: MyCFDI, include_pdf=True):
     preferred_filename = invoice.filename
